@@ -29,3 +29,13 @@ class DynamoKeyValueStore(BaseModel):
 
     def set(self, key: str, value: str) -> None:
         self._table.put_item(Item={"id": key, "Data": value})
+
+
+class MockDynamoKeyValueStore(BaseModel):
+    _store: dict[str, str] = PrivateAttr(default_factory=dict)
+
+    def get(self, key: str) -> str | None:
+        return self._store.get(key)
+
+    def set(self, key: str, value: str) -> None:
+        self._store[key] = value
